Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: chrome/common/extensions/extension_switch_utils.cc

Issue 10511015: Rename --enable-off-store-extension-install to --enable-easy-off... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/extensions/extension_switch_utils.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension_switch_utils.cc
diff --git a/chrome/common/extensions/extension_switch_utils.cc b/chrome/common/extensions/extension_switch_utils.cc
index 36d8a8046cfe38144c591b47521b9ab131e33484..6f9d00cf33f40f80ec62abd95456e5bbaf1468fa 100644
--- a/chrome/common/extensions/extension_switch_utils.cc
+++ b/chrome/common/extensions/extension_switch_utils.cc
@@ -11,14 +11,14 @@ namespace extensions {
namespace switch_utils {
-bool IsOffStoreInstallEnabled() {
- // Disabling off-store installation is not yet implemented for Aura. Not sure
- // what the Aura equivalent for this UI is.
+bool IsEasyOffStoreInstallEnabled() {
+ // Disabling easy off-store installation is not yet implemented for Aura. Not
+ // sure what the Aura equivalent for this UI is.
#if defined(USE_AURA)
return true;
#else
return CommandLine::ForCurrentProcess()->HasSwitch(
- switches::kEnableOffStoreExtensionInstall);
+ switches::kEnableEasyOffStoreExtensionInstall);
#endif
}
« no previous file with comments | « chrome/common/extensions/extension_switch_utils.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698